.. This file is generated from sphinx-notes/template.
   You need to consider modifying the TEMPLATE or modifying THIS FILE.

====================
sphinxnotes-lilypond
====================

.. image:: https://img.shields.io/github/actions/workflow/status/sphinx-notes/lilypond/pages.yml
   :target: https://sphinx.silverrainz.me/lilypond
   :alt: Documentation Status

.. image:: https://img.shields.io/github/license/sphinx-notes/lilypond
   :target: https://github.com/sphinx-notes/lilypond/LICENSE
   :alt: Open Source License

.. image:: https://img.shields.io/pypi/v/sphinxnotes-lilypond.svg
   :target: https://pypi.python.org/pypi/sphinxnotes-lilypond
   :alt: PyPI Package

.. image:: https://img.shields.io/pypi/dw/sphinxnotes-lilypond
   :target: https://pypi.python.org/pypi/sphinxnotes-lilypond
   :alt: PyPI Package Downloads

Sphinx extension for embedding LilyPond scores.

* Documentation: https://sphinx.silverrainz.me/lilypond
* Source: https://github.com/sphinx-notes/lilypond
* Changelog: https://sphinx.silverrainz.me/lilypond/changelog.html
* Tracker: https://github.com/sphinx-notes/lilypond/issues
* Download: https://pypi.org/project/sphinxnotes-lilypond/#files
